View source: R/causal_effect.R
| causal_effect | R Documentation |
Identify a causal effect of the form P(y|do(x),z) from P(v) in
G.
causal_effect(g, y, x = character(0), z = character(0), v = integer(0))
g |
A |
y |
A |
x |
A |
z |
An optional |
v |
An optional named |
An object of class query which is a list with the following
components:
id
A logical value that is TRUE if the query is identifiable and
FALSE otherwise.
formula
A functional object expressing the causal effect in terms
of the joint probability distribution P(v) for identifiable queries
or NULL if the query is not identifiable.
data
The available data, for causal_effect this is always
"observations"
causaleffect
The original query P(y|do(x),z) as a probability
object.
undefined
A logical value, this is always FALSE for
causaleffect
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.