| functional | R Documentation |
Identifying functionals are more complicated probabilistic expressions
that cannot be expressed as simple observational or interventional
probabilities using probability().
functional(sumset = NULL, terms = NULL, numerator = NULL, denominator = NULL)
## S3 method for class 'functional'
format(x, ...)
## S3 method for class 'functional'
print(x, ...)
sumset |
A |
terms |
A |
numerator |
A |
denominator |
A |
x |
A |
... |
Additional arguments passed to |
When formatted via print or format, the arguments are
prioritized in the following order if conflicting definitions are given:
(sumset, terms), (numerator, denominator).
An object of class functional, which is a list containing
all of the arguments of the constructor.
A character representation of the functional object
in LaTeX syntax.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.